@@ -146,7 +146,7 @@ class KDiff3App : public QSplitter
 
     /** open a file and load it into the document*/
     void slotFileOpen();
-    void slotFileOpen2(const QString& fn1, const QString& fn2, const QString& fn3, const QString& ofn,
+    void slotFileOpen2(QStringList &errors, const QString& fn1, const QString& fn2, const QString& fn3, const QString& ofn,
                        const QString& an1, const QString &an2, const QString& an3, TotalDiffStatus* pTotalDiffStatus);
 
     void slotFileNameChanged(const QString& fileName, e_SrcSelector winIdx);
@@ -318,8 +318,8 @@ class KDiff3App : public QSplitter
     QSplitter* m_pMainSplitter;
     QWidget* m_pMainWidget;
     QWidget* m_pMergeWindowFrame;
-    ReversibleScrollBar* m_pHScrollBar;
-    QScrollBar* m_pDiffVScrollBar;
+    ReversibleScrollBar* m_pHScrollBar = nullptr;
+    QScrollBar* m_pDiffVScrollBar = nullptr;
     QScrollBar* m_pMergeVScrollBar;
 
     DiffTextWindow* m_pDiffTextWindow1;
@@ -395,8 +395,8 @@ class KDiff3App : public QSplitter
     KToolBar* toolBar(QLatin1String);
     KDiff3Part* m_pKDiff3Part;
     KParts::MainWindow* m_pKDiff3Shell;
-    bool m_bAutoFlag;
-    bool m_bAutoMode;
+    bool m_bAutoFlag = false;
+    bool m_bAutoMode = false;
     void recalcWordWrap(int visibleTextWidthForPrinting = -1);
     bool m_bRecalcWordWrapPosted;
     void setHScrollBarRange();
