@@ -142,6 +142,8 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
     // so painting must be suppressed
     if(bGUI) setLockPainting(true);
 
+    //insure merge result window never has stale iterators.
+    if(m_pMergeResultWindow) m_pMergeResultWindow->clearMergeList();
     m_diff3LineList.clear();
     m_diff3LineVector.clear();
 
@@ -157,28 +159,25 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
         // First get all input data.
         pp.setInformation(i18n("Loading A"));
 
+        qCInfo(kdeMain) << i18n("Loading A: %1", m_sd1.getFilename());
         if(bUseCurrentEncoding)
-            errors = m_sd1.readAndPreprocess(m_sd1.getEncoding(), false);
+            m_sd1.readAndPreprocess(m_sd1.getEncoding(), false);
         else
-            errors = m_sd1.readAndPreprocess(m_pOptions->m_pEncodingA, m_pOptions->m_bAutoDetectUnicodeA);
-
-        if(!errors.isEmpty())
-        {
-            KMessageBox::errorList(m_pOptionDialog, i18n("Errors occurred during pre-processing of file A."), errors);
-        }
+            m_sd1.readAndPreprocess(m_pOptions->m_pEncodingA, m_pOptions->m_bAutoDetectUnicodeA);
 
         pp.step();
 
         pp.setInformation(i18n("Loading B"));
-        if(bUseCurrentEncoding)
-            errors = m_sd2.readAndPreprocess(m_sd2.getEncoding(), false);
-        else
-            errors = m_sd2.readAndPreprocess(m_pOptions->m_pEncodingB, m_pOptions->m_bAutoDetectUnicodeB);
+        qCInfo(kdeMain) << "Loading B: " << m_sd2.getFilename();
 
-        if(!errors.isEmpty())
-            KMessageBox::errorList(m_pOptionDialog, i18n("Errors occurred during pre-processing of file B."), errors);
+        if(bUseCurrentEncoding)
+            m_sd2.readAndPreprocess(m_sd2.getEncoding(), false);
+        else
+            m_sd2.readAndPreprocess(m_pOptions->m_pEncodingB, m_pOptions->m_bAutoDetectUnicodeB);
 
         pp.step();
+        errors.append(m_sd1.getErrors());
+        errors.append(m_sd2.getErrors());
     }
     else
     {
@@ -188,8 +187,8 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
             pp.setMaxNofSteps(6); // 3 comparisons, 3 finediffs
     }
 
-    if(pTotalDiffStatus)
-        pTotalDiffStatus->reset();
+    pTotalDiffStatus->reset();
+
     if(errors.isEmpty())
     {
         // Run the diff.
@@ -224,12 +223,9 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
             {
                 pp.setInformation(i18n("Loading C"));
                 if(bUseCurrentEncoding)
-                    errors = m_sd3.readAndPreprocess(m_sd3.getEncoding(), false);
+                    m_sd3.readAndPreprocess(m_sd3.getEncoding(), false);
                 else
-                    errors = m_sd3.readAndPreprocess(m_pOptions->m_pEncodingC, m_pOptions->m_bAutoDetectUnicodeC);
-
-                if(!errors.isEmpty())
-                    KMessageBox::errorList(m_pOptionDialog, i18n("Errors occurred during pre-processing of file C."), errors);
+                    m_sd3.readAndPreprocess(m_pOptions->m_pEncodingC, m_pOptions->m_bAutoDetectUnicodeC);
 
                 pp.step();
             }
@@ -313,6 +309,7 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
                 pTotalDiffStatus->bTextBEqC = false;
             }
         }
+        errors.append(m_sd3.getErrors());
     }
     else
     {
@@ -338,7 +335,7 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
         oldHeights = m_pMainSplitter->sizes();
 
     initView();
-    m_pMergeResultWindow->initActions(actionCollection());
+    m_pMergeResultWindow->connectActions();
 
     if(m_pDirectoryMergeSplitter->isVisible())
     {
@@ -390,14 +387,7 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, bool bLoadFiles, boo
         pTotalDiffStatus);
     m_pMergeResultWindowTitle->setFileName(m_outputFilename.isEmpty() ? QString("unnamed.txt") : m_outputFilename);
 
-    if(!bGUI)
-    {
-        // We now have all needed information. The rest below is only for GUI-activation.
-        m_sd1.reset();
-        m_sd2.reset();
-        m_sd3.reset();
-    }
-    else
+    if(bGUI)
     {
         m_pOverview->init(&m_diff3LineList, m_bTripleDiff);
         m_pDiffVScrollBar->setValue(0);
@@ -536,12 +526,12 @@ void KDiff3App::resizeMergeResultWindow()
 
 void KDiff3App::scrollDiffTextWindow(int deltaX, int deltaY)
 {
-    if(deltaY != 0)
+    if(deltaY != 0 && m_pDiffVScrollBar != nullptr)
     {
         m_pDiffVScrollBar->setValue(m_pDiffVScrollBar->value() + deltaY);
         m_pOverview->setRange(m_pDiffVScrollBar->value(), m_pDiffVScrollBar->pageStep());
     }
-    if(deltaX != 0)
+    if(deltaX != 0 && m_pHScrollBar != nullptr)
         m_pHScrollBar->QScrollBar::setValue(m_pHScrollBar->value() + deltaX);
 }
 
@@ -953,15 +943,23 @@ void KDiff3App::keyPressEvent(QKeyEvent* keyEvent)
             break;
         case Qt::Key_Home:
             if(bCtrl)
-                m_pDiffVScrollBar->setValue(0);
+            {
+                if(m_pDiffVScrollBar != nullptr) m_pDiffVScrollBar->setValue(0);
+            }
             else
-                m_pHScrollBar->setValue(0);
+            {
+                if(m_pHScrollBar != nullptr)  m_pHScrollBar->setValue(0);
+            }
             break;
         case Qt::Key_End:
             if(bCtrl)
-                m_pDiffVScrollBar->setValue(m_pDiffVScrollBar->maximum());
+            {
+                if(m_pDiffVScrollBar != nullptr) m_pDiffVScrollBar->setValue(m_pDiffVScrollBar->maximum());
+            }
             else
-                m_pHScrollBar->setValue(m_pHScrollBar->maximum());
+            {
+                if(m_pHScrollBar != nullptr) m_pHScrollBar->setValue(m_pHScrollBar->maximum());
+            }
             break;
         default:
             break;
@@ -1091,20 +1089,21 @@ void KDiff3App::slotFileOpen()
                 m_pDirectoryMergeSplitter->hide();
                 mainInit();
 
-                if((!m_sd1.isEmpty() && !m_sd1.hasData()) ||
-                   (!m_sd2.isEmpty() && !m_sd2.hasData()) ||
-                   (!m_sd3.isEmpty() && !m_sd3.hasData()))
+                if((!m_sd1.getErrors().isEmpty()) ||
+                   (!m_sd2.getErrors().isEmpty()) ||
+                   (!m_sd3.getErrors().isEmpty()))
                 {
                     QString text(i18n("Opening of these files failed:"));
                     text += "\n\n";
-                    if(!m_sd1.isEmpty() && !m_sd1.hasData())
-                        text += " - " + m_sd1.getAliasName() + '\n';
-                    if(!m_sd2.isEmpty() && !m_sd2.hasData())
-                        text += " - " + m_sd2.getAliasName() + '\n';
-                    if(!m_sd3.isEmpty() && !m_sd3.hasData())
-                        text += " - " + m_sd3.getAliasName() + '\n';
+                    if(!m_sd1.getErrors().isEmpty())
+                        text += " - " + m_sd1.getAliasName() + '\n' + m_sd1.getErrors().join('\n') + '\n';
+                    if(!m_sd2.getErrors().isEmpty())
+                        text += " - " + m_sd2.getAliasName() + '\n' + m_sd2.getErrors().join('\n') + '\n';
+                    if(!m_sd3.getErrors().isEmpty())
+                        text += " - " + m_sd3.getAliasName() + '\n' + m_sd3.getErrors().join('\n') + '\n';
 
                     KMessageBox::sorry(this, text, i18n("File open error"));
+
                     continue;
                 }
             }
@@ -1116,7 +1115,7 @@ void KDiff3App::slotFileOpen()
     slotStatusMsg(i18n("Ready."));
 }
 
-void KDiff3App::slotFileOpen2(const QString& fn1, const QString& fn2, const QString& fn3, const QString& ofn,
+void KDiff3App::slotFileOpen2(QStringList &errors, const QString& fn1, const QString& fn2, const QString& fn3, const QString& ofn,
                               const QString& an1, const QString& an2, const QString& an3, TotalDiffStatus* pTotalDiffStatus)
 {
     if(!canContinue()) return;
@@ -1155,7 +1154,16 @@ void KDiff3App::slotFileOpen2(const QString& fn1, const QString& fn2, const QStr
         mainInit(pTotalDiffStatus);
 
         if(pTotalDiffStatus != nullptr)
+        {
+            errors.append(m_sd1.getErrors());
+            errors.append(m_sd2.getErrors());
+            errors.append(m_sd3.getErrors());
+            //Only time this could ever happen so move here to allow for error retrieval.
+            m_sd1.reset();
+            m_sd2.reset();
+            m_sd3.reset();
             return;
+        }
 
         if(!((!m_sd1.isEmpty() && !m_sd1.hasData()) ||
            (!m_sd2.isEmpty() && !m_sd2.hasData()) ||
@@ -1172,12 +1180,14 @@ void KDiff3App::slotFileOpen2(const QString& fn1, const QString& fn2, const QStr
 
 void KDiff3App::slotFileNameChanged(const QString& fileName, e_SrcSelector winIdx)
 {
+    QStringList errors;
     QString fn1 = m_sd1.getFilename();
     QString an1 = m_sd1.getAliasName();
     QString fn2 = m_sd2.getFilename();
     QString an2 = m_sd2.getAliasName();
     QString fn3 = m_sd3.getFilename();
     QString an3 = m_sd3.getAliasName();
+
     if(winIdx == A)
     {
         fn1 = fileName;
@@ -1194,7 +1204,7 @@ void KDiff3App::slotFileNameChanged(const QString& fileName, e_SrcSelector winId
         an3 = "";
     }
 
-    slotFileOpen2(fn1, fn2, fn3, m_outputFilename, an1, an2, an3, nullptr);
+    slotFileOpen2(errors, fn1, fn2, fn3, m_outputFilename, an1, an2, an3, nullptr);
 }
 
 void KDiff3App::slotEditCut()
@@ -1564,7 +1574,7 @@ void KDiff3App::slotClipboardChanged()
 {
     const QClipboard* clipboard = QApplication::clipboard();
     const QMimeData* mimeData = clipboard->mimeData();
-    if(mimeData->hasText())
+    if(mimeData && mimeData->hasText())
     {
         QString s = clipboard->text();
         editPaste->setEnabled(!s.isEmpty());
